@@ -1,4 +1,4 @@
-# Copyright (C) 2023,2024 Giovanni Fulco
+# Copyright (C) 2023,2024,2025 Giovanni Fulco
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -13,11 +13,17 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
+from enum import Enum
 from tidalapi import Quality as TidalQuality
 
 plugin_name: str = "tidal"
 
-tidal_plugin_release: str = "0.7.10"
+tidal_plugin_release: str = "0.8.1"
+
+
+class EnvironmentVariableName(Enum):
+    UPMPD_UPNPHOSTPORT = "UPMPD_UPNPHOSTPORT"
+
 
 listening_queue_action_key: str = "action"
 listening_queue_button_title_key: str = "button_title"
@@ -73,6 +79,36 @@ tile_image_expiration_time_sec: int = 86400
 oauth2_credentials_file_name: str = "oauth2.credentials.json"
 pkce_credentials_file_name: str = "pkce.credentials.json"
 
+
+class ConfigurationParameterData:
+
+    def __init__(self, key: str, default_value: any):
+        self.__key: str = key
+        self.__default_value: any = default_value
+
+    @property
+    def key(self) -> str:
+        return self.__key
+
+    @property
+    def default_value(self) -> any:
+        return self.__default_value
+
+
+class ConfigurationParameter(Enum):
+    ALLOW_FAVORITE_ACTIONS = ConfigurationParameterData("allowfavoriteactions", False)
+    ALLOW_BOOKMARK_ACTIONS = ConfigurationParameterData("allowbookmarkactions", False)
+    ALLOW_STATISTICS_ACTIONS = ConfigurationParameterData("allowstatisticsactions", False)
+
+    @property
+    def key(self) -> str:
+        return self.value.key
+
+    @property
+    def default_value(self) -> any:
+        return self.value.default_value
+
+
 # remove if not really used
 default_max_album_tracks_per_page: int = 30
 
